aboutsummaryrefslogtreecommitdiffstats
path: root/Installer
diff options
context:
space:
mode:
Diffstat (limited to 'Installer')
-rw-r--r--Installer/CHANGES.txt6
-rw-r--r--Installer/FilelistSUNSolaris26I386.java.skel11
-rw-r--r--Installer/FilelistTool.java2
-rw-r--r--Installer/GL4JInst.java2
-rw-r--r--Installer/GL4JInst_cacert_ns.html2
-rw-r--r--Installer/MachineCtrl.java57
-rw-r--r--Installer/index.html2
-rwxr-xr-xInstaller/makeMSIESignedCab.sh7
-rwxr-xr-xInstaller/makeMScert.sh4
-rwxr-xr-xInstaller/makeNetscapeSignedJar-Unix.sh6
-rwxr-xr-xInstaller/makeNetscapeSignedJar-Win32.sh6
-rw-r--r--Installer/versiondef.sh2
12 files changed, 69 insertions, 38 deletions
diff --git a/Installer/CHANGES.txt b/Installer/CHANGES.txt
index dae13df..45159fe 100644
--- a/Installer/CHANGES.txt
+++ b/Installer/CHANGES.txt
@@ -12,13 +12,17 @@ This CHANGES starts with version 2.00 !
GL4Java Installer 2.00 is based upon version 1.05, by Ron Cemer !
-Last Changes: 6th Dezember 2001 (Version 2.07)
+Last Changes: Dezember 11, 2001 (Version 2.82)
-----------------
TOP = new
DOWN = old
-----------------
+Dezember 11, 2001 (Version 2.82):
+ o Installer added SunOS intel x86 support (jau)
+ o little bugfixes (jau)
+
Dezember 6, 2001 (Version 2.07):
o The Installer now installs also:
diff --git a/Installer/FilelistSUNSolaris26I386.java.skel b/Installer/FilelistSUNSolaris26I386.java.skel
new file mode 100644
index 0000000..32dccac
--- /dev/null
+++ b/Installer/FilelistSUNSolaris26I386.java.skel
@@ -0,0 +1,11 @@
+
+public class FilelistSUNSolaris26I386
+ implements FilelistOS
+{
+ public static final String version = "_MAJV_._MINV_._BUGV_._RELV_";
+
+ public static final String archiv = "../binpkg/libGL4Java_MAJV_._MINV_._BUGV_._RELV_-SUNOS-57-x86.zip";
+
+ public String getVersion() { return version; }
+ public String getArchiv() { return archiv; }
+}
diff --git a/Installer/FilelistTool.java b/Installer/FilelistTool.java
index b256702..45ba28a 100644
--- a/Installer/FilelistTool.java
+++ b/Installer/FilelistTool.java
@@ -28,6 +28,8 @@ public class FilelistTool
{
if(mctrl.isOsArchSPARC)
return new FilelistSUNSolaris26Sparc();
+ else if(mctrl.isOsArchX86)
+ return new FilelistSUNSolaris26I386();
} else if(mctrl.unixFlavor==mctrl.unixFlavor_Irix)
{
if(mctrl.isOsArchMIPS)
diff --git a/Installer/GL4JInst.java b/Installer/GL4JInst.java
index 0149da6..459beef 100644
--- a/Installer/GL4JInst.java
+++ b/Installer/GL4JInst.java
@@ -24,7 +24,7 @@ public class GL4JInst
static private final String gl4javaWWW =
"http://www.jausoft.com/Files/Java/1.1.X/GL4Java/Installer";
- static private final String version = "2.07";
+ static private final String version = "2.82";
static private final String cannot_install_title =
"Cannot install GL4Java";
diff --git a/Installer/GL4JInst_cacert_ns.html b/Installer/GL4JInst_cacert_ns.html
index 8d42c9d..de0dec1 100644
--- a/Installer/GL4JInst_cacert_ns.html
+++ b/Installer/GL4JInst_cacert_ns.html
@@ -49,7 +49,7 @@ Certificate Authority" box comes up:
IS AN EXTRA SECURITY PRECAUTION.
<p>When asked for a name, enter the following name, exactly as shown: GL4Java
<br>
-<p><b><a href="x509.crt">Click here to import the signing certificate.</a> </b> Valid from <b> Thu Dec 06, 2001 to Wed Mar 06, 2002 </b>
+<p><b><a href="x509.crt">Click here to import the signing certificate.</a> </b> Valid from <b> Tue Dec 11, 2001 to Mon Mar 11, 2002 </b>
<br>
<p>After you have imported the certificate, <b><a href="GL4JInst_ns.html">Click
here to begin the GL4Java installation.</a></b>
diff --git a/Installer/MachineCtrl.java b/Installer/MachineCtrl.java
index 664f47f..e0fc43c 100644
--- a/Installer/MachineCtrl.java
+++ b/Installer/MachineCtrl.java
@@ -665,6 +665,7 @@ public class MachineCtrl
if(DEBUG)
System.out.println("> added java2 lib/ext classpath ...");
}
+
if (classpath != null)
{
while ( (classpath != null) && (classpath.length() > 0) )
@@ -722,31 +723,36 @@ public class MachineCtrl
FileTool.MkdirWithParents(this, thisfile);
- if (isUnix)
- {
- switch (unixFlavor)
- {
- case unixFlavor_Linux:
- os_natives = new String("/usr/lib");
- break;
- case unixFlavor_Solaris:
- os_natives = new String("/usr/lib");
- break;
- case unixFlavor_Aix:
- os_natives = new String("/usr/lib");
- break;
- case unixFlavor_Irix:
- os_natives = new String("/usr/lib");
- break;
- }
- }
- else if(os_natives==null||os_natives.length()==0)
- os_natives = thispath.substring(0,thispath.length()-7) + "bin";
break;
}
}
}
}
+
+ if(os_natives==null||os_natives.length()==0)
+ {
+ if (isUnix)
+ {
+ switch (unixFlavor)
+ {
+ case unixFlavor_Linux:
+ os_natives = new String("/usr/lib");
+ break;
+ case unixFlavor_Solaris:
+ os_natives = new String("/usr/lib");
+ break;
+ case unixFlavor_Aix:
+ os_natives = new String("/usr/lib");
+ break;
+ case unixFlavor_Irix:
+ os_natives = new String("/usr/lib");
+ break;
+ }
+ } else {
+ os_natives = jvmHome+"/bin";
+ }
+ }
+
if(jvmHome!=null && jvmHome!="null")
{
if(isWin32)
@@ -823,7 +829,7 @@ public class MachineCtrl
{
}
*/
- } // if (isNetscapeJvm)
+ } // if (isNetscapeJvm || isSunJvm)
return true;
}
@@ -1137,6 +1143,9 @@ public class MachineCtrl
tf_browser_natives.requestFocus();
tf_browser_natives.getToolkit().beep();
}
+ } else {
+ browser_natives = null;
+ System.out.println("Set Browser-Native-Dir to: null");
}
} catch (Exception ex) {
ex.printStackTrace();
@@ -1181,6 +1190,9 @@ public class MachineCtrl
tf_os_natives.requestFocus();
tf_os_natives.getToolkit().beep();
}
+ } else {
+ os_natives = null;
+ System.out.println("Set OS-Native-Dir to: null");
}
} catch (Exception ex) {
ex.printStackTrace();
@@ -1230,6 +1242,9 @@ public class MachineCtrl
} else if(src.equals(tf_browser_natives))
{
checkTextFields();
+ } else if(src.equals(tf_os_natives))
+ {
+ checkTextFields();
} else if(src.equals(buttonFileClasses))
{
FileDialog fd =
diff --git a/Installer/index.html b/Installer/index.html
index 0eb405c..06e4fde 100644
--- a/Installer/index.html
+++ b/Installer/index.html
@@ -15,7 +15,7 @@ the java classes to your browsers directory !
<p>If you are ready to begin, <a href="GL4JInst.html">Click here to start
the setup procedure.</a>
<br>
-(JavaScript is needed - does not work for MacOS !)
+(JavaScript is needed - does not work for Java2-Enabled-Browsers, or MacOS !)
</center>
<hr>
<br>&nbsp;
diff --git a/Installer/makeMSIESignedCab.sh b/Installer/makeMSIESignedCab.sh
index 1ead186..b2c405f 100755
--- a/Installer/makeMSIESignedCab.sh
+++ b/Installer/makeMSIESignedCab.sh
@@ -4,9 +4,9 @@
# The Microsft signing keys were created using the Microsoft makecert and
# cert2spc utilities, as follows:
-# makecert -nscp -r -n CN=GL4JInst GL4JInst281.cer -sv GL4JInst281.pvk
+# makecert -nscp -r -n CN=GL4JInst GL4JInst282.cer -sv GL4JInst282.pvk
# (when prompted for a password, click "None")
-# cert2spc GL4JInst281.cer GL4JInst281.spc
+# cert2spc GL4JInst282.cer GL4JInst282.spc
rm -f *.class GL4JInst.cab
/MSJVM/BIN/jvc -nomessage -x- -cp:p .\;..\\CAPSAPI_CLASSES.ZIP *.java
@@ -14,6 +14,5 @@ rm -f *.class GL4JInst.cab
. versionundef.sh
/MSJVM/Bin/cabarc N GL4JInst.cab *.class
-# signcode -j javasign.dll -jp low -spc GL4JInst.spc -k GL4JInst GL4JInst.cab
-/MSJVM/Bin/signcode -j javasign.dll -jp low -spc GL4JInst281.spc -v GL4JInst281.pvk GL4JInst.cab
+/MSJVM/Bin/signcode -j javasign.dll -jp low -spc GL4JInst282.spc -v GL4JInst282.pvk GL4JInst.cab
rm *.class
diff --git a/Installer/makeMScert.sh b/Installer/makeMScert.sh
index 785da63..1a46082 100755
--- a/Installer/makeMScert.sh
+++ b/Installer/makeMScert.sh
@@ -1,7 +1,7 @@
#! /bin/sh
# The Microsft signing keys were created using the Microsoft makecert and
-//D/MSJAVASDK/Bin/makecert -nscp -r -n CN=GL4JInst271 GL4JInst271.cer -sv GL4JInst271.pvk
+/MSJVM/Bin/makecert -nscp -r -n CN=GL4JInst282 GL4JInst282.cer -sv GL4JInst282.pvk
# (when prompted for a password, click "None")
-//D/MSJAVASDK/Bin/cert2spc GL4JInst271.cer GL4JInst271.spc
+/MSJVM/Bin/cert2spc GL4JInst282.cer GL4JInst282.spc
diff --git a/Installer/versiondef.sh b/Installer/versiondef.sh
index 88ba6f3..b804bbb 100644
--- a/Installer/versiondef.sh
+++ b/Installer/versiondef.sh
@@ -1,6 +1,6 @@
MAJV=2
MINV=8
-BUGV=1
+BUGV=2
RELV=0
echo creating installer for version $MAJV.$MINV.$BUGV.$RELV !
diff --git a/Installer/makeNetscapeSignedJar-Unix.sh b/Installer/makeNetscapeSignedJar-Unix.sh
index 437e7b7..1f0da90 100755
--- a/Installer/makeNetscapeSignedJar-Unix.sh
+++ b/Installer/makeNetscapeSignedJar-Unix.sh
@@ -5,9 +5,9 @@
# The Netscape signing keys were created using the Netscape signtool
# utility, as follows:
# copy key3.db and cert7.db from one of the users directories.
-# signtool -d . -G GL4JInst281
+# signtool -d . -G GL4JInst282
# Enter the following information:
# certificate common name: GL4JInst281
# organization: GL4Java Development Team
# organization unit: GL4JInst
# state or province: NRW
@@ -27,7 +27,7 @@ javac -classpath ".:../capsapi_classes.zip" *.java
. versionundef.sh
rm -rf META-INF
-signtool -d . -e .class -k GL4JInst281 -Z GL4JInst_ns.jar -c9 --norecurse .
+signtool -d . -e .class -k GL4JInst282 -Z GL4JInst_ns.jar -c9 --norecurse .
rm -rf META-INF
rm -f key3.db cert7.db *.class
@@ -5,9 +5,9 @@
# Enter the following information:
-# certificate common name: GL4JInst281
+# certificate common name: GL4JInst282
# organization: GL4Java Development Team
# organization unit: GL4JInst
diff --git a/Installer/makeNetscapeSignedJar-Win32.sh b/Installer/makeNetscapeSignedJar-Win32.sh
index bb86f85..ef44100 100755
--- a/Installer/makeNetscapeSignedJar-Win32.sh
+++ b/Installer/makeNetscapeSignedJar-Win32.sh
@@ -5,9 +5,9 @@
# The Netscape signing keys were created using the Netscape signtool
# utility, as follows:
# copy key3.db and cert7.db from one of the users directories.
-# signtool -d . -G GL4JInst204
+# signtool -d . -G GL4JInst282
# Enter the following information:
# certificate common name: GL4JInst204
# organization: GL4Java Development Team
# organization unit: GL4JInst
# state or province: NRW
@@ -27,7 +27,7 @@ javac -classpath ".;..\\capsapi_classes.zip" *.java
. versionundef.sh
rm -rf META-INF
-signtool -d . -e .class -k GL4JInst205 -Z GL4JInst_ns.jar -c9 --norecurse .
+signtool -d . -e .class -k GL4JInst282 -Z GL4JInst_ns.jar -c9 --norecurse .
rm -rf META-INF
rm -f key3.db cert7.db *.class
@@ -5,9 +5,9 @@
# Enter the following information:
-# certificate common name: GL4JInst204
+# certificate common name: GL4JInst282
# organization: GL4Java Development Team
# organization unit: GL4JInst